Adds support for Forge2d, the Box2d-based physics engine, to your Flame games.
flame_forge2d
This library acts as a bridge between Forge2D (our bindings for Box2D) and the Flame game engine.
Installation
Check pub.dev for the latest version, and also
remember to add the latest version of Flame to your
pubspec.yaml file.
Examples
In the example folder of this directory you can find some examples, and you can also find some examples in the Forge2D repository.
Documentation
Some more documentation can be found here.
Migrating from 0.19
Version 0.20 is built on Forge2D 0.15, which replaced the pure Dart port of Box2D 2.x with bindings for Box2D v3, so the whole API changed. See the flame_forge2d migration guide and the Forge2D migration guide.