body_component library

Classes

BodyComponent<T extends Forge2DGame<Forge2DWorld>>
Since a pure BodyComponent doesn't have anything drawn on top of it, it is a good idea to turn on debugMode for it so that the bodies can be seen
ShapeSpec
A pairing of a ShapeGeometry with an optional ShapeDef, used by BodyComponent.shapeSpecs to describe the shapes that should be created on the body.