renderBody property
Specifies if the body's shapes should be rendered.
renderBody is true by default for BodyComponent, if set to false the body's shapes wont be rendered.
If you render something on top of the BodyComponent, or doesn't want it to be seen, you probably want to set it to false.
Implementation
bool renderBody;