shapeSpecs property
The default implementation of createBody will create these shapes on the Body that it creates from bodyDef.
Implementation
List<ShapeSpec>? shapeSpecs;
The default implementation of createBody will create these shapes on the Body that it creates from bodyDef.
List<ShapeSpec>? shapeSpecs;