ShapeSpec class

A pairing of a ShapeGeometry with an optional ShapeDef, used by BodyComponent.shapeSpecs to describe the shapes that should be created on the body.

Constructors

ShapeSpec(ShapeGeometry geometry, [ShapeDef? definition])
const

Properties

definition ShapeDef?
The definition that the shape is created with, or the Forge2D defaults when null.
final
geometry ShapeGeometry
The geometry of the shape, for example a Circle or a Polygon.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited