definition property
The definition that the shape is created with, or the Forge2D defaults when null.
Implementation
final ShapeDef? definition;
The definition that the shape is created with, or the Forge2D defaults when null.
final ShapeDef? definition;