points property
The initial contact points, recorded before the solver ran.
Only available for begin-touch events of non-sensor shapes.
Implementation
final List<ContactPoint>? points;
The initial contact points, recorded before the solver ran.
Only available for begin-touch events of non-sensor shapes.
final List<ContactPoint>? points;