Circle class final

A circle with an optional local offset.

Mirrors the native b2Circle type.

Inheritance

Constructors

Circle({required double radius, Vector2? center})
Creates a circle with the given radius, optionally offset from the body origin by center.

Properties

center → Vector2
The local center of the circle.
final
hashCode → int
The hash code for this object.
no setterinherited
radius → double
The radius of the circle.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited