SensorEvents class
The sensor events of the last step.
Constructors
-
SensorEvents({required List<
SensorEvent> begin, required List<SensorEvent> end}) - Creates the event collection.
Properties
-
begin
→ List<
SensorEvent> -
The overlaps that started.
final
-
end
→ List<
SensorEvent> -
The overlaps that ended.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited