mousePressDetector property

void Function(PointerDownEvent event)? get mousePressDetector
inherited

Set by the PointerMoveDispatcher to receive mouse press events from the game widget so it can fire onHoverCancel on hovered HoverCallbacks components when the user presses a button while hovering.

Implementation

void Function(PointerDownEvent event)? get mousePressDetector =>
    _mousePressDetector;
set mousePressDetector (void newMousePressDetector(PointerDownEvent event)?)
inherited

Implementation

set mousePressDetector(
  void Function(PointerDownEvent event)? newMousePressDetector,
) {
  _mousePressDetector = newMousePressDetector;
  refreshWidget();
}