onLoad method
Initializes Forge2D and then loads the game.
On the web this is what loads the Box2D WebAssembly module, and no physics world can be created before it has completed, which is why the world of a Forge2DWorld is created lazily.
Subclasses that override this must await super.onLoad() before
they create any bodies, or the game will throw on the web.
Implementation
@override
Future<void> onLoad() async {
await initializeForge2D(lengthUnitsPerMeter: lengthUnitsPerMeter);
await super.onLoad();
}