updateTree method
This method traverses the component tree and calls update on all its
children according to their priority order, relative to the
priority of the direct siblings, not the children or the ancestors.
This method cannot be overridden. Components that need to customize how
their subtree is traversed (changing the effective dt, skipping
children, or updating them manually) mix in CustomTraversal and
override its CustomTraversal.updateSubtree method.
Implementation
@nonVirtual
void updateTree(double dt) {
if (_isTraversalBarrier) {
(this as CustomTraversal).updateSubtree(dt);
} else {
_defaultUpdateSubtree(dt);
}
}