ContactHitEvent class
Two shapes hit each other faster than the world's hit event threshold.
Constructors
Properties
- approachSpeed → double
-
The closing speed of the shapes at the impact point, in meters per
second.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- normal → Vector2
-
The impact normal, pointing from shapeA to shapeB.
final
- point → Vector2
-
The impact point in world coordinates.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shapeA → Shape
-
The first shape.
final
- shapeB → Shape
-
The second shape.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited