contactEventsDispatcher property
Routes the contact and sensor events that the physics world generated during a step to the ContactCallbacks in the involved userData.
Implementation
final ContactEventsDispatcher contactEventsDispatcher;
Routes the contact and sensor events that the physics world generated during a step to the ContactCallbacks in the involved userData.
final ContactEventsDispatcher contactEventsDispatcher;